@@ -16,20 +16,18 @@
 
 // This tests a conforming extension
 
-
 #include <queue>
 #include <cassert>
 
 #include "test_macros.h"
 #include "MoveOnly.h"
 
-int main(int, char**)
-{
+int main(int, char**) {
 #if defined(_LIBCPP_VERSION)
-    {
-        typedef std::priority_queue<MoveOnly> C;
-        static_assert(std::is_nothrow_default_constructible<C>::value, "");
-    }
+  {
+    typedef std::priority_queue<MoveOnly> C;
+    static_assert(std::is_nothrow_default_constructible<C>::value, "");
+  }
 #endif
 
   return 0;
